geom_star provides the multiple geometric shape to create scatter plot or other point plot, it is like the 'geom_point' of 'ggplot2'. Note: the 'left-triangle' (17, 19) and 'right-triangle' (18, 20) are developed to plot the 'triangle-heatmap'. Their centers are not in their internal, but the center of hypotenuse.
geom_star(
mapping = NULL,
data = NULL,
na.rm = FALSE,
stat = "identity",
position = "identity",
show.legend = NA,
inherit.aes = TRUE,
...
)polygonal point layer
Set of aesthetic mappings created by aes(). If specified and
inherit.aes = TRUE (the default), it is combined with the default mapping
at the top level of the plot. You must supply mapping if there is no plot
mapping.
The data to be displayed in this layer. There are three options:
If NULL, the default, the data is inherited from the plot
data as specified in the call to ggplot().
A data.frame, or other object, will override the plot
data. All objects will be fortified to produce a data frame. See
fortify() for which variables will be created.
A function will be called with a single argument,
the plot data. The return value must be a data.frame, and
will be used as the layer data. A function can be created
from a formula (e.g. ~ head(.x, 10)).
If `FALSE`, the default, missing values are removed with a warning. If `TRUE`, missing values are silently removed.
The statistical transformation to use on the data for this
layer, either as a ggproto Geom subclass or as a string naming the
stat stripped of the stat_ prefix (e.g. "count" rather than
"stat_count")
Position adjustment, either as a string naming the adjustment
(e.g. "jitter" to use position_jitter), or the result of a call to a
position adjustment function. Use the latter if you need to change the
settings of the adjustment.
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.
FALSE never includes, and TRUE always includes.
It can also be a named logical vector to finely select the aesthetics to
display.
If FALSE, overrides the default aesthetics,
rather than combining with them. This is most useful for helper functions
that define both data and aesthetics and shouldn't inherit behaviour from
the default plot specification, e.g. borders().
Other arguments passed on to layer.
geom_star() understands the following aesthetics (required aesthetics are in bold):
x
y
alpha
angle
colour
fill
group
phase
size
starshape
starstroke
subset
Learn more about setting these aesthetics in vignette("ggplot2-specs").
Shuangbin Xu
starshape the shape of point, default is 1 (star shape).
starstroke control the thickness of margin of point, default is 0.5.
size the size of point, default is 1.5.
colour the colour of margin, default is 'black'.
fill the colour of fill, default is NA.
alpha the transparency of fill, default is 1.
angle control the angle of rotation of point, default is 0.
subset subset the data frame which meet conditions to display.
library(ggplot2)
p <- ggplot(iris, aes(x=Sepal.Length,
y=Sepal.Width,
starshape=Species)) +
geom_star(size=4)
p
Run the code above in your browser using DataLab